export interface Food {
  id: string;
  name: string;
  category: string;
  calories: number; // per 100g
  nutrients: Nutrients;
  glycemicIndex?: number;
  allergens?: string[];
}

export interface Nutrients {
  protein: number;
  carbohydrates: number;
  fat: number;
  fiber: number;
  sodium: number;
  vitamins: Record<string, number>;
  minerals: Record<string, number>;
}

export interface MealRecord {
  id: string;
  userId: string;
  mealType: "breakfast" | "lunch" | "dinner" | "snack";
  foods: FoodItem[];
  totalCalories: number;
  totalNutrients: Nutrients;
  recordTime: Date;
  images?: string[];
}

export interface FoodItem {
  foodId: string;
  foodName: string;
  quantity: number; // grams
  calories: number;
  nutrients: Nutrients;
}

export interface DietPlan {
  id: string;
  userId: string;
  name: string;
  type: "weight_loss" | "weight_gain" | "maintenance" | "diabetic" | "hypertension";
  targetCalories: number;
  targetNutrients: Nutrients;
  duration: number; // days
  meals: PlannedMeal[];
  createdDate: Date;
  isActive: boolean;
}

export interface PlannedMeal {
  mealType: "breakfast" | "lunch" | "dinner" | "snack";
  foods: FoodItem[];
  targetCalories: number;
  instructions?: string;
}
