export interface Exercise {
  id: string;
  name: string;
  category: "cardio" | "strength" | "flexibility" | "balance" | "sports";
  difficulty: "beginner" | "intermediate" | "advanced";
  duration: number; // minutes
  caloriesPerMinute: number;
  equipment?: string[];
  instructions: string[];
  images?: string[];
  videos?: string[];
}

export interface ExerciseRecord {
  id: string;
  userId: string;
  exerciseId: string;
  exerciseName: string;
  duration: number; // minutes
  intensity: "low" | "medium" | "high";
  caloriesBurned: number;
  heartRate?: {
    average: number;
    maximum: number;
  };
  distance?: number; // for cardio exercises
  sets?: ExerciseSet[]; // for strength exercises
  recordTime: Date;
  notes?: string;
}

export interface ExerciseSet {
  reps: number;
  weight?: number;
  restTime?: number;
}

export interface ExercisePlan {
  id: string;
  userId: string;
  name: string;
  goal: "weight_loss" | "muscle_gain" | "endurance" | "strength" | "general_fitness";
  difficulty: "beginner" | "intermediate" | "advanced";
  duration: number; // weeks
  weeklySchedule: WeeklySchedule[];
  createdDate: Date;
  isActive: boolean;
}

export interface WeeklySchedule {
  dayOfWeek: number; // 0-6
  exercises: PlannedExercise[];
  restDay: boolean;
}

export interface PlannedExercise {
  exerciseId: string;
  exerciseName: string;
  duration?: number;
  sets?: number;
  reps?: number;
  weight?: number;
  restTime?: number;
}
