export interface HealthProfile {
  id: string;
  userId: string;
  basicInfo: BasicHealthInfo;
  medicalHistory: MedicalHistory;
  familyHistory: FamilyHistory;
  allergies: Allergy[];
  medications: CurrentMedication[];
  emergencyContacts: EmergencyContact[];
  healthGoals: HealthGoal[];
  preferences: HealthPreferences;
  createdDate: Date;
  lastUpdated: Date;
}

export interface BasicHealthInfo {
  height: number; // cm
  weight: number; // kg
  bloodType: "A" | "B" | "AB" | "O";
  rhFactor: "+" | "-";
  birthDate: Date;
  gender: "male" | "female" | "other";
  occupation: string;
  smokingStatus: "never" | "former" | "current";
  drinkingStatus: "never" | "occasional" | "regular";
  exerciseFrequency: "never" | "rarely" | "sometimes" | "often" | "daily";
}

export interface MedicalHistory {
  surgeries: Surgery[];
  chronicDiseases: string[];
  significantIllnesses: SignificantIllness[];
  hospitalizations: Hospitalization[];
  vaccinationHistory: Vaccination[];
}

export interface Surgery {
  procedure: string;
  date: Date;
  hospital: string;
  surgeon?: string;
  notes?: string;
}

export interface SignificantIllness {
  condition: string;
  diagnosisDate: Date;
  treatmentDate?: Date;
  severity: "mild" | "moderate" | "severe";
  resolved: boolean;
  notes?: string;
}

export interface Hospitalization {
  reason: string;
  admissionDate: Date;
  dischargeDate: Date;
  hospital: string;
  department: string;
  notes?: string;
}

export interface Vaccination {
  vaccineName: string;
  date: Date;
  batchNumber?: string;
  location: string;
  nextDueDate?: Date;
}

export interface FamilyHistory {
  conditions: FamilyCondition[];
}

export interface FamilyCondition {
  condition: string;
  relationship: string;
  ageOfOnset?: number;
  notes?: string;
}

export interface Allergy {
  allergen: string;
  type: "food" | "drug" | "environmental" | "other";
  severity: "mild" | "moderate" | "severe";
  reactions: string[];
  diagnosisDate?: Date;
}

export interface CurrentMedication {
  name: string;
  dosage: string;
  frequency: string;
  startDate: Date;
  endDate?: Date;
  prescribedBy: string;
  purpose: string;
}

export interface EmergencyContact {
  name: string;
  relationship: string;
  phoneNumber: string;
  address?: string;
  isPrimary: boolean;
}

export interface HealthGoal {
  id: string;
  type: "weight" | "fitness" | "chronic_disease" | "lifestyle" | "other";
  description: string;
  targetValue?: number;
  currentValue?: number;
  unit?: string;
  targetDate: Date;
  priority: "high" | "medium" | "low";
  status: "active" | "achieved" | "paused" | "cancelled";
  progress: number; // percentage
}

export interface HealthPreferences {
  reminderSettings: ReminderSettings;
  privacySettings: PrivacySettings;
  communicationPreferences: CommunicationPreferences;
  unitPreferences: UnitPreferences;
}

export interface ReminderSettings {
  medicationReminders: boolean;
  appointmentReminders: boolean;
  exerciseReminders: boolean;
  mealReminders: boolean;
  checkupReminders: boolean;
  reminderTime: string; // HH:mm format
}

export interface PrivacySettings {
  shareHealthData: boolean;
  shareWithDoctors: boolean;
  shareWithFamily: boolean;
  anonymousResearch: boolean;
}

export interface CommunicationPreferences {
  email: boolean;
  sms: boolean;
  pushNotifications: boolean;
  weeklyReports: boolean;
  monthlyReports: boolean;
}

export interface UnitPreferences {
  weightUnit: "kg" | "lb";
  heightUnit: "cm" | "ft_in";
  temperatureUnit: "celsius" | "fahrenheit";
  distanceUnit: "km" | "mile";
}
