/**
 * 健康数据格式化工具
 */

// 格式化血压显示
export const formatBloodPressure = (systolic: number, diastolic: number): string => {
  return `${systolic}/${diastolic} mmHg`;
};

// 格式化BMI显示
export const formatBMI = (bmi: number): string => {
  return `${bmi.toFixed(1)} kg/m²`;
};

// 格式化心率显示
export const formatHeartRate = (heartRate: number): string => {
  return `${heartRate} bpm`;
};

// 格式化体温显示
export const formatTemperature = (temperature: number): string => {
  return `${temperature.toFixed(1)}°C`;
};

// 格式化血氧显示
export const formatBloodOxygen = (oxygen: number): string => {
  return `${oxygen}%`;
};

// 格式化体重显示
export const formatWeight = (weight: number): string => {
  return `${weight.toFixed(1)} kg`;
};

// 格式化身高显示
export const formatHeight = (height: number): string => {
  return `${height} cm`;
};

// 格式化血糖显示
export const formatBloodSugar = (sugar: number): string => {
  return `${sugar.toFixed(1)} mmol/L`;
};

// 格式化运动时长
export const formatExerciseDuration = (minutes: number): string => {
  if (minutes < 60) {
    return `${minutes}分钟`;
  } else {
    const hours = Math.floor(minutes / 60);
    const remainingMinutes = minutes % 60;
    return remainingMinutes > 0 ? `${hours}小时${remainingMinutes}分钟` : `${hours}小时`;
  }
};

// 格式化卡路里
export const formatCalories = (calories: number): string => {
  return `${calories} 千卡`;
};

// 格式化用药频率
export const formatMedicationFrequency = (frequency: string): string => {
  const frequencyMap: Record<string, string> = {
    once_daily: "每日1次",
    twice_daily: "每日2次",
    three_times_daily: "每日3次",
    four_times_daily: "每日4次",
    every_other_day: "隔日1次",
    once_weekly: "每周1次",
    as_needed: "必要时服用",
  };

  return frequencyMap[frequency] || frequency;
};

// 格式化时间范围
export const formatTimeRange = (startTime: Date, endTime: Date): string => {
  const formatTime = (date: Date) => {
    return date.toLocaleTimeString("zh-CN", {
      hour: "2-digit",
      minute: "2-digit",
      hour12: false,
    });
  };

  const isSameDay = startTime.toDateString() === endTime.toDateString();

  if (isSameDay) {
    return `${formatTime(startTime)} - ${formatTime(endTime)}`;
  } else {
    return `${startTime.toLocaleDateString("zh-CN")} ${formatTime(startTime)} - ${endTime.toLocaleDateString("zh-CN")} ${formatTime(endTime)}`;
  }
};
